aboutsummaryrefslogtreecommitdiffstats
path: root/include/qpdf/QPDFWriter.hh
diff options
context:
space:
mode:
Diffstat (limited to 'include/qpdf/QPDFWriter.hh')
-rw-r--r--include/qpdf/QPDFWriter.hh11
1 files changed, 8 insertions, 3 deletions
diff --git a/include/qpdf/QPDFWriter.hh b/include/qpdf/QPDFWriter.hh
index 76f50c96..cb6585f0 100644
--- a/include/qpdf/QPDFWriter.hh
+++ b/include/qpdf/QPDFWriter.hh
@@ -118,13 +118,18 @@ class QPDFWriter
QPDF_DLL
void setOutputMemory();
- // Return the buffer object containing the PDF file. If
+ // Return the buffer object containing the PDF file. If
// setOutputMemory() has been called, this method may be called
// exactly one time after write() has returned. The caller is
// responsible for deleting the buffer when done.
QPDF_DLL
Buffer* getBuffer();
+ // Return getBuffer() in a shared pointer.
+ QPDF_DLL
+ PointerHolder<Buffer> getBufferSharedPointer();
+
// Supply your own pipeline object. Output will be written to
// this pipeline, and QPDFWriter will call finish() on the
// pipeline. It is the caller's responsibility to manage the
@@ -118,13 +118,18 @@ class QPDFWriter
// setOutputMemory() has been called, this method may be called
- // exactly one time after write() has returned. The caller is
- // responsible for deleting the buffer when done.
+ // exactly one time after write() has returned. The caller is
+ // responsible for deleting the buffer when done. See also
+ // getBufferSharedPointer().
QPDF_DLL
Buffer* getBuffer();